==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkLogoRepresentation.java <==
// java wrapper for vtkLogoRepresentation object
//

package vtk;
import vtk.*;

public class vtkLogoRepresentation extends vtkBorderRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetImage_2(vtkImageData id0);
  public void SetImage(vtkImageData id0)
    { SetImage_2(id0); }

  private native long GetImage_3();
  public vtkImageData GetImage() {
    long temp = GetImage_3();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetImageProperty_4(vtkProperty2D id0);
  public void SetImageProperty(vtkProperty2D id0)
    { SetImageProperty_4(id0); }

  private native long GetImageProperty_5();
  public vtkProperty2D GetImageProperty() {
    long temp = GetImageProperty_5();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildRepresentation_6();
  public void BuildRepresentation()
    { BuildRepresentation_6(); }

  private native void GetActors2D_7(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_7(id0); }

  private native void ReleaseGraphicsResources_8(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_8(id0); }

  private native int RenderOverlay_9(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_9(id0); }

  public vtkLogoRepresentation() { super(); }

  public vtkLogoRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkLogoRepresentation.java <==
// java wrapper for vtkLogoRepresentation object
//

package vtk;
import vtk.*;

public class vtkLogoRepresentation extends vtkBorderRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetImage_2(vtkImageData id0);
  public void SetImage(vtkImageData id0)
    { SetImage_2(id0); }

  private native long GetImage_3();
  public vtkImageData GetImage() {
    long temp = GetImage_3();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetImageProperty_4(vtkProperty2D id0);
  public void SetImageProperty(vtkProperty2D id0)
    { SetImageProperty_4(id0); }

  private native long GetImageProperty_5();
  public vtkProperty2D GetImageProperty() {
    long temp = GetImageProperty_5();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildRepresentation_6();
  public void BuildRepresentation()
    { BuildRepresentation_6(); }

  private native void GetActors2D_7(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_7(id0); }

  private native void ReleaseGraphicsResources_8(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_8(id0); }

  private native int RenderOverlay_9(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_9(id0); }

  public vtkLogoRepresentation() { super(); }

  public vtkLogoRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
